@@ -15,6 +15,7 @@
 #ifndef DAISYKIT_FLOWS_PUSHUP_COUNTER_FLOW_H_
 #define DAISYKIT_FLOWS_PUSHUP_COUNTER_FLOW_H_
 
+#include "daisykitsdk/common/types.h"
 #include "daisykitsdk/models/body_detector.h"
 #include "daisykitsdk/models/pose_detector_movenet.h"
 
@@ -23,22 +24,23 @@
 #include <opencv2/opencv.hpp>
 #include <string>
 
+#ifdef __ANDROID__
+#include <android/asset_manager_jni.h>
+#endif
+
 namespace daisykit {
 namespace flows {
 class HumanPoseMoveNetFlow {
  public:
   HumanPoseMoveNetFlow(const std::string& config_str);
+#ifdef __ANDROID__
+  HumanPoseMoveNetFlow(AAssetManager* mgr, const std::string& config_str);
+#endif
 
-  void Process(cv::Mat& rgb);
-  void DrawResult(cv::Mat& rgb);
+  std::vector<types::ObjectWithKeypoints> Process(cv::Mat& rgb);
+  void DrawResult(cv::Mat& rgb, std::vector<types::ObjectWithKeypoints>& poses);
 
  private:
-  std::vector<types::Object> bodies_;
-  std::mutex bodies_lock_;
-
-  std::vector<std::vector<types::Keypoint>> keypoints_;
-  std::mutex keypoints_lock_;
-
   models::BodyDetector* body_detector_;
   models::PoseDetectorMoveNet* pose_detector_;
 };
