@@ -14,12 +14,18 @@
 
 #include "daisykitsdk/models/image_model.h"
 
+#include <iostream>
 #include <string>
 #include <vector>
 
 namespace daisykit {
 namespace models {
 
+ImageModel::ImageModel(int input_size) {
+  input_height_ = input_size;
+  input_width_ = input_size;
+}
+
 ImageModel::ImageModel(int input_width, int input_height) {
   input_height_ = input_height;
   input_width_ = input_width;
@@ -29,5 +35,14 @@ int ImageModel::InputWidth() { return input_width_; }
 
 int ImageModel::InputHeight() { return input_height_; }
 
+int ImageModel::InputSize() {
+  if (input_width_ != input_height_)
+    std::cerr
+        << "Input width is different from Input height. Getting input size "
+           "may be wrong."
+        << std::endl;
+  return input_width_;
+}
+
 }  // namespace models
 }  // namespace daisykit
